==> ember-resize-0.2.0.tgz: package/addon/services/resize.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { oneWay, readOnly } from '@ember-decorators/object/computed';
import { getWithDefault, set } from '@ember/object';
import Evented from '@ember/object/evented';
import { cancel, debounce } from '@ember/runloop';
import Service from '@ember/service';
import { classify } from '@ember/string';
class ResizeService extends Service.extend(Evented) {
    constructor() {
        super(...arguments);
        this._oldWidth = window.innerWidth;
        this._oldHeight = window.innerHeight;
        this._oldWidthDebounced = window.innerWidth;
        this._oldHeightDebounced = window.innerHeight;
        this._setDefaults();
        this._onResizeHandler = (evt) => {
            this._fireResizeNotification(evt);
            const scheduledDebounce = debounce(this, this._fireDebouncedResizeNotification, evt, this.get('debounceTimeout'));
            this._scheduledDebounce = scheduledDebounce;
        };
        if (typeof FastBoot === 'undefined') {
            this._installResizeListener();
        }
    }
    destroy() {
        this._super(...arguments);
        if (typeof FastBoot === 'undefined') {
            this._uninstallResizeListener();
        }
        this._cancelScheduledDebounce();
        return this;
    }
    _setDefaults() {
        const defaults = getWithDefault(this, 'resizeServiceDefaults', {});
        Object.keys(defaults).map((key) => {
            const classifiedKey = classify(key);
            const defaultKey = `default${classifiedKey}`;
            return set(this, defaultKey, defaults[key]);
        });
    }
    _hasWindowSizeChanged(w, h, debounced = false) {
        const wKey = debounced ? '_oldWidthDebounced' : '_oldWidth';
        const hKey = debounced ? '_oldHeightDebounced' : '_oldHeight';
        return ((this.get('widthSensitive') && w !== this.get(wKey)) ||
            (this.get('heightSensitive') && h !== this.get(hKey)));
    }
    _updateCachedWindowSize(w, h, debounced = false) {
        const wKey = debounced ? '_oldWidthDebounced' : '_oldWidth';
        const hKey = debounced ? '_oldHeightDebounced' : '_oldHeight';
        this.set(wKey, w);
        this.set(hKey, h);
    }
    _installResizeListener() {
        if (!this._onResizeHandler) {
            return;
        }
        window.addEventListener('resize', this._onResizeHandler);
    }
    _uninstallResizeListener() {
        if (!this._onResizeHandler) {
            return;
        }
        window.removeEventListener('resize', this._onResizeHandler);
    }
    _cancelScheduledDebounce() {
        if (!this._scheduledDebounce) {
            return;
        }
        cancel(this._scheduledDebounce);
    }
    _fireResizeNotification(evt) {
        const { innerWidth, innerHeight } = window;
        if (this._hasWindowSizeChanged(innerWidth, innerHeight)) {
            this.trigger('didResize', evt);
            this._updateCachedWindowSize(innerWidth, innerHeight);
        }
    }
    _fireDebouncedResizeNotification(evt) {
        const { innerWidth, innerHeight } = window;
        if (this._hasWindowSizeChanged(innerWidth, innerHeight, true)) {
            this.trigger('debouncedDidResize', evt);
            this._updateCachedWindowSize(innerWidth, innerHeight, true);
        }
    }
}
__decorate([
    oneWay('defaultDebounceTimeout')
], ResizeService.prototype, "debounceTimeout", void 0);
__decorate([
    oneWay('defaultWidthSensitive')
], ResizeService.prototype, "widthSensitive", void 0);
__decorate([
    oneWay('defaultHeightSensitive')
], ResizeService.prototype, "heightSensitive", void 0);
__decorate([
    readOnly('_oldWidth')
], ResizeService.prototype, "screenWidth", void 0);
__decorate([
    readOnly('_oldHeight')
], ResizeService.prototype, "screenHeight", void 0);
export default ResizeService;

==> ember-resize-0.2.2.tgz: package/addon/services/resize.js <==
import { computed, getWithDefault, set } from '@ember/object';
import Evented from '@ember/object/evented';
import { cancel, debounce } from '@ember/runloop';
import Service from '@ember/service';
import { classify } from '@ember/string';
class ResizeService extends Service.extend(Evented, {
    debounceTimeout: computed.oneWay('defaultDebounceTimeout'),
    heightSensitive: computed.oneWay('defaultHeightSensitive'),
    screenHeight: computed.readOnly('_oldHeight'),
    screenWidth: computed.readOnly('_oldWidth'),
    widthSensitive: computed.oneWay('defaultWidthSensitive'),
}) {
    constructor() {
        super(...arguments);
        this._oldWidth = window.innerWidth;
        this._oldHeight = window.innerHeight;
        this._oldWidthDebounced = window.innerWidth;
        this._oldHeightDebounced = window.innerHeight;
        this._setDefaults();
        this._onResizeHandler = (evt) => {
            this._fireResizeNotification(evt);
            const scheduledDebounce = debounce(this, this._fireDebouncedResizeNotification, evt, this.get('debounceTimeout'));
            this._scheduledDebounce = scheduledDebounce;
        };
        if (typeof FastBoot === 'undefined') {
            this._installResizeListener();
        }
    }
    destroy() {
        this._super(...arguments);
        if (typeof FastBoot === 'undefined') {
            this._uninstallResizeListener();
        }
        this._cancelScheduledDebounce();
        return this;
    }
    _setDefaults() {
        const defaults = getWithDefault(this, 'resizeServiceDefaults', {});
        Object.keys(defaults).map((key) => {
            const classifiedKey = classify(key);
            const defaultKey = `default${classifiedKey}`;
            return set(this, defaultKey, defaults[key]);
        });
    }
    _hasWindowSizeChanged(w, h, debounced = false) {
        const wKey = debounced ? '_oldWidthDebounced' : '_oldWidth';
        const hKey = debounced ? '_oldHeightDebounced' : '_oldHeight';
        return ((this.get('widthSensitive') && w !== this.get(wKey)) ||
            (this.get('heightSensitive') && h !== this.get(hKey)));
    }
    _updateCachedWindowSize(w, h, debounced = false) {
        const wKey = debounced ? '_oldWidthDebounced' : '_oldWidth';
        const hKey = debounced ? '_oldHeightDebounced' : '_oldHeight';
        this.set(wKey, w);
        this.set(hKey, h);
    }
    _installResizeListener() {
        if (!this._onResizeHandler) {
            return;
        }
        window.addEventListener('resize', this._onResizeHandler);
    }
    _uninstallResizeListener() {
        if (!this._onResizeHandler) {
            return;
        }
        window.removeEventListener('resize', this._onResizeHandler);
    }
    _cancelScheduledDebounce() {
        if (!this._scheduledDebounce) {
            return;
        }
        cancel(this._scheduledDebounce);
    }
    _fireResizeNotification(evt) {
        const { innerWidth, innerHeight } = window;
        if (this._hasWindowSizeChanged(innerWidth, innerHeight)) {
            this.trigger('didResize', evt);
            this._updateCachedWindowSize(innerWidth, innerHeight);
        }
    }
    _fireDebouncedResizeNotification(evt) {
        const { innerWidth, innerHeight } = window;
        if (this._hasWindowSizeChanged(innerWidth, innerHeight, true)) {
            this.trigger('debouncedDidResize', evt);
            this._updateCachedWindowSize(innerWidth, innerHeight, true);
        }
    }
}
export default ResizeService;
